<?php

namespace Drupal\social_tracking\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Social Tracking entity.
 *
 * @ConfigEntityType(
 *   id = "social_tracking",
 *   label = @Translation("Social Tracking"),
 *   module = "social_tracking",
 *   handlers = {
 *     "list_builder" = "Drupal\social_tracking\Controller\SocialTrackingListBuilder",
 *     "form" = {
 *       "add" = "Drupal\social_tracking\Form\SocialTrackingEntityForm",
 *       "edit" = "Drupal\social_tracking\Form\SocialTrackingEntityForm",
 *       "delete" = "Drupal\social_tracking\Form\SocialTrackingEntityDeleteForm"
 *     }
 *   },
 *   config_prefix = "tracking",
 *   admin_permission = "administer social tracking",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   links = {
 *     "add-form" = "/admin/config/services/social_tracking/add",
 *     "edit-form" = "/admin/config/services/social_tracking/manage/{social_tracking}",
 *     "delete-form" = "/admin/config/services/social_tracking/manage/{social_tracking}/delete",
 *     "collection" = "/admin/config/services/social_tracking"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "description",
 *     "tracking_enabled",
 *     "tracking_id",
 *     "tracking_provider",
 *     "exclude_admin_pages",
 *     "excluded_roles"
 *   }
 * )
 */
class SocialTracking extends ConfigEntityBase implements SocialTrackingEntityInterface {

  /**
   * The Social Tracking ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Social Tracking label.
   *
   * @var string
   */
  protected $label;

  /**
   * The Social Tracking description.
   *
   * @var string
   */
  protected $description = '';

  /**
   * The Social Tracking Enabled.
   *
   * @var string
   */
  protected $tracking_enabled = FALSE;

  /**
   * The Social Tracking ID.
   *
   * @var string
   */
  protected $tracking_id = NULL;

  /**
   * The Social Tracking Plugin Provider.
   *
   * @var string
   */
  protected $tracking_provider = NULL;

  /**
   * The Social Tracking Exclude admin pages.
   *
   * @var string
   */
  protected $exclude_admin_pages = FALSE;

  /**
   * The Social Tracking Excluded roles.
   *
   * @var array
   */
  protected $excluded_roles = [];

  /**
   * {@inheritdoc}
   */
  public function getTrackingId() {
    return $this->get('tracking_id');
  }

  /**
   * {@inheritdoc}
   */
  public function isEnabled() {
    return (bool) $this->get('tracking_enabled');
  }

  /**
   * {@inheritdoc}
   */
  public function isExcludeAdminPages() {
    return (bool) $this->get('exclude_admin_pages');
  }

  /**
   * {@inheritdoc}
   */
  public function getExcludedRoles() {
    return $this->get('excluded_roles');
  }

  /**
   * {@inheritdoc}
   */
  public function getTrackingProvider() {
    return $this->get('tracking_provider');
  }

}
